@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::CollapseStack::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::CollapseStack::VERSION = '0.28';
+  $Reply::Plugin::CollapseStack::VERSION = '0.29';
 }
 use strict;
 use warnings;
@@ -11,6 +11,11 @@ use warnings;
 
 use base 'Reply::Plugin';
 
+{
+    local @SIG{qw(__DIE__ __WARN__)};
+    require Carp::Always;
+}
+
 
 sub new {
     my $class = shift;
@@ -22,6 +27,22 @@ sub new {
     return $self;
 }
 
+sub compile {
+    my $self = shift;
+    my ($next, @args) = @_;
+
+    local $SIG{__DIE__} = \&Carp::Always::_die;
+    $next->(@args);
+}
+
+sub execute {
+    my $self = shift;
+    my ($next, @args) = @_;
+
+    local $SIG{__DIE__} = \&Carp::Always::_die;
+    $next->(@args);
+}
+
 sub mangle_error {
     my $self = shift;
     my $error = shift;
@@ -59,7 +80,7 @@ Reply::Plugin::CollapseStack - display error stack traces only on demand
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
